==> DiscreteGapStatistic_0.1.0.tar.gz: DiscreteGapStatistic/R/data.R <==
#' mass data
#'
#' @format ## `data.frame`
#' Data extracted from the `likert` R package.
#' Results from an administration of the Math Anxiety Scale Survey.
#' First Column records student gender either Female or Male.
#' All statement answers have 5 possible ordinal categorical items: Strongly Disagree, Disagree,
#' Neutral, Agree, Strongly Agree.
#' \describe{
#'   \item{Gender}{Gender}
#'   \item{I find math interesting.}{Math interesting}
#'   \item{I get uptight during math tests.}{Uptight with math tests}
#'   \item{I think that I will use math in the future.}{Use math in the future}
#'   \item{Mind goes blank and I am unable to think clearly when doing my math test.}{Mind goes blank in math tests}
#'   \item{Math relates to my life.}{Math relates to own life}
#'   \item{I worry about my ability to solve math problems.}{Worry about ability math problem solving}
#'   \item{I get a sinking feeling when I try to do math problems.}{Sinking feeling doing math problems}
#'   \item{I find math challenging.}{Math is challenging}
#'   \item{Mathematics makes me feel nervous.}{Nervousness with math}
#'   \item{I would like to take more math classes.}{Take more math classes}
#'   \item{Mathematics makes me feel uneasy.}{Uneasy feeling with math}
#'   \item{Math is one of my favorite subjects.}{Favorite subject is math}
#'   \item{I enjoy learning with mathematics.}{Enjoy learning math}
#'   \item{Mathematics makes me feel confused.}{Confused with math}
#' }
#' @source <https://rdrr.io/cran/likert/man/mass.html>
"mass"

#' Concussion Data
#'
#' @format ## `data.frame`
#' A data frame with 109 rows and 21 columns.
#' Severity rating recorded as categorical responses from c1 (none) to c7 (severe).
#' \describe{
#'   \item{Q1: Headache}{Headache}
#'   \item{Q2: Nausea}{Nausea}
#'   \item{Q3: Balance problems}{Balance problems}
#'   \item{Q4: Dizziness}{Dizziness}
#'   \item{Q5: Fatigue}{Fatigue}
#'   \item{Q6: Sleep more}{Sleeping more than usual}
#'   \item{Q7: Drowsiness}{Drowsiness}
#'   \item{Q8: Sensibility to light}{Sensibility to light}
#'   \item{Q9: Sensibility to noice}{Sensibility to noice}
#'   \item{Q10: Irritability}{Irritability}
#'   \item{Q11: Sadness}{Sadness}
#'   \item{Q12: Nervousness}{Nervousness/Anxiousness}
#'   \item{Q13: More emotional}{Feeling more emotional}
#'   \item{Q14: Feeling slowed down}{Feeling slowed down}
#'   \item{Q15: Feeling mentally foggy}{Feeling mentally foggy}
#'   \item{Q16: Difficulty concentrating}{Difficulty concentrating}
#'   \item{Q17: Difficulty remembering}{Difficulty remembering}
#'   \item{Q18: Visual problem}{Visual problems}
#'   \item{Q19: Confusion}{Confusion}
#'   \item{Q20: Feeling clumsy}{Feeling clumsy}
#'   \item{Q21: Answer slowlier}{Answer slowlier}
#' }
"concussion"

==> DiscreteGapStatistic_1.1.2.tar.gz: DiscreteGapStatistic/R/data.R <==
#' mass data
#'
#' Data extracted from the `likert` R package.
#' Results from an administration of the Math Anxiety Scale Survey.
#' First Column records student gender either Female or Male.
#' All statement answers have 5 possible ordinal categorical items:
#' Strongly Disagree, Disagree, Neutral, Agree, Strongly Agree.
#'
#' @format ## `data.frame`
#' \describe{
#'   \item{Gender}{Gender}
#'   \item{I find math interesting.}{Math interesting}
#'   \item{I get uptight during math tests.}{Uptight with math tests}
#'   \item{I think that I will use math in the future.}{Use math in the future}
#'   \item{Mind goes blank and I am unable to think clearly when doing my math test.}{Mind goes blank in math tests}
#'   \item{Math relates to my life.}{Math relates to own life}
#'   \item{I worry about my ability to solve math problems.}{Worry about ability math problem solving}
#'   \item{I get a sinking feeling when I try to do math problems.}{Sinking feeling doing math problems}
#'   \item{I find math challenging.}{Math is challenging}
#'   \item{Mathematics makes me feel nervous.}{Nervousness with math}
#'   \item{I would like to take more math classes.}{Take more math classes}
#'   \item{Mathematics makes me feel uneasy.}{Uneasy feeling with math}
#'   \item{Math is one of my favorite subjects.}{Favorite subject is math}
#'   \item{I enjoy learning with mathematics.}{Enjoy learning math}
#'   \item{Mathematics makes me feel confused.}{Confused with math}
#' }
#' @source <https://rdrr.io/cran/likert/man/mass.html>
"mass"

#' Concussion Data
#'
#' A data frame with 109 observations and 21 questions.
#' Severity rating recorded as categorical responses from c1 (none) to c7 (severe).
#'
#' @format ## `data.frame`
#'
#' \describe{
#'   \item{Q1: Headache}{Headache}
#'   \item{Q2: Nausea}{Nausea}
#'   \item{Q3: Balance problems}{Balance problems}
#'   \item{Q4: Dizziness}{Dizziness}
#'   \item{Q5: Fatigue}{Fatigue}
#'   \item{Q6: Sleep more}{Sleeping more than usual}
#'   \item{Q7: Drowsiness}{Drowsiness}
#'   \item{Q8: Sensibility to light}{Sensibility to light}
#'   \item{Q9: Sensibility to noice}{Sensibility to noice}
#'   \item{Q10: Irritability}{Irritability}
#'   \item{Q11: Sadness}{Sadness}
#'   \item{Q12: Nervousness}{Nervousness/Anxiousness}
#'   \item{Q13: More emotional}{Feeling more emotional}
#'   \item{Q14: Feeling slowed down}{Feeling slowed down}
#'   \item{Q15: Feeling mentally foggy}{Feeling mentally foggy}
#'   \item{Q16: Difficulty concentrating}{Difficulty concentrating}
#'   \item{Q17: Difficulty remembering}{Difficulty remembering}
#'   \item{Q18: Visual problem}{Visual problems}
#'   \item{Q19: Confusion}{Confusion}
#'   \item{Q20: Feeling clumsy}{Feeling clumsy}
#'   \item{Q21: Answer slowlier}{Answer slowlier}
#' }
"concussion"
